# DynaSig-ML package
"Dynamical Signatures - Machine Learning" Python package.

If you use DynaSig-ML, please cite these two articles:  
https://doi.org/10.1101/2022.07.06.499058  
https://doi.org/10.1093/bioinformatics/btab189

Online documentation and step-by-step tutorial: https://dynasigml.readthedocs.io  
Companion repository for the tutorial: https://github.com/gregorpatof/dynasigml_vim2_example
